@@ -72,7 +72,7 @@ def classifier_free_guidance(
             return logits
 
         assert not self.training, 'condition scaling can only be invoked at evaluation, not training'
-        null_logits = fn(*args, **kwargs_with_cond_dropout)
+        null_logits = fn(self, *args, **kwargs_with_cond_dropout)
         return null_logits + (logits - null_logits) * cond_scale
 
     return inner
